@@ -12,22 +12,22 @@ import click
 @click.version_option(__version__)
 @click.option(
     "--recid",
-    help="Unique ID of the record in the upstream source",
-    required=True,
+    help="Record ID of the resource the upstream digital repository. Required by every pipeline but local.",
 )
 @click.option(
     "-s",
     "--source",
-    help="Select source pipeline",
+    help="Select source pipeline from the supported ones.",
     required=True,
     type=click.Choice(
-        ["cds", "ilcdoc", "cod", "zenodo", "inveniordm", "indico", "local"], case_sensitive=False
+        ["cds", "ilcdoc", "cod", "zenodo", "inveniordm", "indico", "local", "ilcagenda"],
+        case_sensitive=False,
     ),
 )
 @click.option(
     "-d",
     "--dry-run",
-    help="Skip downloads",
+    help="Skip downloads and create a `light` bag, without any payload.",
     default=False,
     is_flag=True,
 )
@@ -36,21 +36,21 @@ import click
     "--alternate-uri",
     help="""
          Use alternative uri instead of https for fetch.txt (e.g. root endpoints 
-         for CERN Open Data instead of http)""",
+         for CERN Open Data instead of http).""",
     default=False,
     is_flag=True,
 )
 @click.option(
     "--verbose",
     "-v",
-    help="Enable logging (verbose, 'info' level)",
+    help="Enable basic logging (verbose, 'info' level).",
     default=False,
     is_flag=True,
 )
 @click.option(
     "--very-verbose",
     "-vv",
-    help="Enable logging (very verbose, 'debug' level)",
+    help="Enable verbose logging (very verbose, 'debug' level).",
     default=False,
     is_flag=True,
 )
@@ -58,31 +58,55 @@ import click
     "--bibdoc",
     "-b",
     help="""
-    Get metadata for a CDS record from the bibdocfile utility.
-    (`/opt/cdsweb/bin/bibdocfile` must be available in the system
-    and the resource must be from CDS)""",
+    [ONLY for Supported Invenio v1 pipelines]
+    Get metadata for a CDS record from the bibdocfile utility
+    (`/opt/cdsweb/bin/bibdocfile` must be available in the system).""",
     default=False,
     is_flag=True,
 )
 @click.option(
     "--bd-ssh-host",
     help="""
-    SSH host to run bibdocfile""",
+    [ONLY for Supported Invenio v1 pipelines]
+    Specify SSH host to run bibdocfile. Access must be promptless.
+    (See documentation for usage and configuration).
+    By default uses the local machine.""",
     default=None,
     is_flag=False,
 )
 @click.option(
     "--target",
     "-t",
-    help="Select destination folder",
+    help="""
+    Output folder for the generated SIP. By default uses the same folder 
+    the tool is being executed from.""",
     type=Text,
     default=None,
     is_flag=False,
 )
 @click.option(
-    "--localsource",
-    "-ls",
-    help="Select the local source folder.",
+    "--source-path",
+    "-sp",
+    help="""[Local source ONLY, required]
+    Set path of the local folder to use as a source.""",
+    type=Text,
+    default=None,
+    is_flag=False,
+)
+@click.option(
+    "--author",
+    "-u",
+    help="[Local source ONLY] Specify the Author of data.",
+    type=Text,
+    default=None,
+    is_flag=False,
+)
+@click.option(
+    "--source-base-path",
+    "-sbp",
+    help="""
+    [Local source ONLY] Specify a part of the path as 
+    relevant for extracting an hierachy.""",
     type=Text,
     default=None,
     is_flag=False,
@@ -91,14 +115,15 @@ def cli(
     recid,
     source,
     target,
-    localsource,
+    source_path,
+    author,
+    source_base_path,
     dry_run,
     alternate_uri,
     verbose,
     very_verbose,
     bibdoc,
     bd_ssh_host,
-
 ):
 
     # Select the desired log level (default is 2, warning)
@@ -116,7 +141,9 @@ def cli(
         source,
         loglevel,
         target,
-        localsource,
+        source_path,
+        author,
+        source_base_path,
         dry_run,
         alternate_uri,
         bibdoc,
