@@ -20,8 +20,8 @@ def process(
     recid,
     source,
     loglevel,
-    target,
-    source_path,
+    target=None,
+    source_path=None,
     author=None,
     source_base_path=None,
     dry_run=False,
